@@ -1,5 +1,6 @@
+from .guardpoint_utils import GuardPointResponse
 from .guardpoint_dataclasses import Area
-from .guardpoint_error import GuardPointError
+from .guardpoint_error import GuardPointError, GuardPointUnauthorized
 
 
 class AreasAPI:
@@ -13,9 +14,14 @@ class AreasAPI:
         code, json_body = self.gp_json_query("GET", headers=headers, url=url)
 
         if code != 200:
-            if isinstance(json_body, dict):
-                if 'error' in json_body:
-                    raise GuardPointError(json_body['error'])
+            error_msg = GuardPointResponse.extract_error_msg(json_body)
+
+            if code == 401:
+                raise GuardPointUnauthorized(f"Unauthorized - ({error_msg})")
+            elif code == 404:  # Not Found
+                raise GuardPointError(f"Cardholder Not Found")
+            else:
+                raise GuardPointError(f"{error_msg}")
 
         if not isinstance(json_body, dict):
             raise GuardPointError("Badly formatted response.")
