@@ -1,13 +1,18 @@
-import json
 import validators
-
-from ._odata_filter import _compose_select
+from .guardpoint_utils import GuardPointResponse
+from ._odata_filter import _compose_filter
 from .guardpoint_dataclasses import Card, Cardholder
-from .guardpoint_error import GuardPointError
+from .guardpoint_error import GuardPointError, GuardPointUnauthorized
 
 
 class CardsAPI:
-    def get_cards(self, count=False):
+    def get_cards(self, count=False, **card_kwargs):
+        # Filter arguments which have to exact match
+        match_args = dict()
+        for k, v in card_kwargs.items():
+            if hasattr(Card, k):
+                match_args[k] = v
+
         url = "/odata/API_Cards"
         headers = {
             'Content-Type': 'application/json',
@@ -15,14 +20,22 @@ class CardsAPI:
         }
 
         if count:
-            url += "?$count=true&$top=0"
+            url_query_params = "?$count=true&$top=0"
+        else:
+            filter_str = _compose_filter(exact_match=match_args)
+            url_query_params = ("?" + filter_str)
 
-        code, json_body = self.gp_json_query("GET", headers=headers, url=url)
+        code, json_body = self.gp_json_query("GET", headers=headers, url=(url+url_query_params))
 
         if code != 200:
-            if isinstance(json_body, dict):
-                if 'error' in json_body:
-                    raise GuardPointError(json_body['error'])
+            error_msg = GuardPointResponse.extract_error_msg(json_body)
+
+            if code == 401:
+                raise GuardPointUnauthorized(f"Unauthorized - ({error_msg})")
+            elif code == 404:  # Not Found
+                raise GuardPointError(f"Cardholder Not Found")
+            else:
+                raise GuardPointError(f"{error_msg}")
 
         if not isinstance(json_body, dict):
             raise GuardPointError("Badly formatted response.")
@@ -53,13 +66,14 @@ class CardsAPI:
         code, json_body = self.gp_json_query("DELETE", headers=headers, url=(url + url_query_params))
 
         if code != 204:  # HTTP NO_CONTENT
-            try:
-                if 'error' in json_body:
-                    raise GuardPointError(json_body['error'])
-                else:
-                    raise GuardPointError(str(code))
-            except Exception:
-                raise GuardPointError(str(code))
+            error_msg = GuardPointResponse.extract_error_msg(json_body)
+
+            if code == 401:
+                raise GuardPointUnauthorized(f"Unauthorized - ({error_msg})")
+            elif code == 404:  # Not Found
+                raise GuardPointError(f"Card Not Found")
+            else:
+                raise GuardPointError(f"{error_msg}")
 
         return True
 
@@ -81,12 +95,12 @@ class CardsAPI:
         code, json_body = self.gp_json_query("PATCH", headers=headers, url=(url + url_query_params), json_body=ch)
 
         if code != 204:  # HTTP NO_CONTENT
-            if 'error' in json_body:
-                raise GuardPointError(json_body['error'])
-            elif 'message' in json_body:
-                raise GuardPointError(json_body['message'])
+            error_msg = GuardPointResponse.extract_error_msg(json_body)
+
+            if code == 401:
+                raise GuardPointUnauthorized(f"Unauthorized - ({error_msg})")
             else:
-                raise GuardPointError(str(code))
+                raise GuardPointError(f"No body - ({code})")
 
         return True
 
