@@ -1,6 +1,6 @@
 import validators
-from .guardpoint_error import GuardPointError
-
+from .guardpoint_utils import GuardPointResponse
+from .guardpoint_error import GuardPointError, GuardPointUnauthorized
 from .guardpoint_dataclasses import CardholderCustomizedField
 
 
@@ -24,11 +24,13 @@ class CustomizedFieldsAPI:
         code, json_body = self.gp_json_query("PATCH", headers=headers, url=(url + url_query_params), json_body=ch)
 
         if code != 204:  # HTTP NO_CONTENT
-            if 'error' in json_body:
-                raise GuardPointError(json_body['error'])
-            elif 'message' in json_body:
-                raise GuardPointError(json_body['message'])
+            error_msg = GuardPointResponse.extract_error_msg(json_body)
+
+            if code == 401:
+                raise GuardPointUnauthorized(f"Unauthorized - ({error_msg})")
+            elif code == 404:  # Not Found
+                raise GuardPointError(f"Cardholder Not Found")
             else:
-                raise GuardPointError(str(code))
+                raise GuardPointError(f"{error_msg}")
 
         return True
