@@ -1,6 +1,6 @@
 import validators
-from .guardpoint_error import GuardPointError
-
+from .guardpoint_utils import GuardPointResponse
+from .guardpoint_error import GuardPointError, GuardPointUnauthorized
 from .guardpoint_dataclasses import CardholderPersonalDetail
 
 
@@ -19,16 +19,18 @@ class PersonalDetailsAPI:
             # 'IgnoreNonEditable': ''
         }
 
-        ch = personal_details.dict(changed_only=True)
+        ch = personal_details.dict(editable_only=True, changed_only=True)
 
         code, json_body = self.gp_json_query("PATCH", headers=headers, url=(url + url_query_params), json_body=ch)
 
         if code != 204:  # HTTP NO_CONTENT
-            if 'error' in json_body:
-                raise GuardPointError(json_body['error'])
-            elif 'message' in json_body:
-                raise GuardPointError(json_body['message'])
+            error_msg = GuardPointResponse.extract_error_msg(json_body)
+
+            if code == 401:
+                raise GuardPointUnauthorized(f"Unauthorized - ({error_msg})")
+            elif code == 404:  # Not Found
+                raise GuardPointError(f"Cardholder Not Found")
             else:
-                raise GuardPointError(str(code))
+                raise GuardPointError(f"{error_msg}")
 
         return True
\ No newline at end of file
