@@ -1,5 +1,9 @@
 from datetime import datetime
-from .guardpoint_dataclasses import Area, Cardholder
+
+import validators
+
+from .guardpoint_dataclasses import Area, Cardholder, CardholderPersonalDetail
+from urllib.parse import quote
 
 
 def _compose_expand(ignore_list, include_list):
@@ -72,9 +76,25 @@ def _compose_filter(search_words=None,
                     areas=None,
                     cardholder_type_name=None,
                     filter_expired=False,
-                    earliest_last_pass=None):
+                    earliest_last_pass=None,
+                    exact_match=None):
     filter_phrases = []
 
+    if exact_match:
+        if isinstance(exact_match, dict):
+            for k, v in exact_match.items():
+                if isinstance(v, str):
+                    if validators.uuid(v):
+                        filter_phrases.append(f"({k}%20eq%20{quote(v)})")
+                    else:
+                        filter_phrases.append(f"({k}%20eq%20'{quote(v)}')")
+                if isinstance(v, (bool, int)):
+                    filter_phrases.append(f"({k}%20eq%20{quote(v)})")
+                if k == "cardholderPersonalDetail" and v.__class__.__name__ == "CardholderPersonalDetail":
+                    details = v.dict(changed_only=True)
+                    for dk, dv in details.items():
+                        filter_phrases.append(f"(CardholderPersonalDetail/{dk}%20eq%20'{quote(dv)}')")
+
     if earliest_last_pass:
         if isinstance(earliest_last_pass, datetime):
             last_pass_date = earliest_last_pass.strftime('%Y-%m-%dT%H:%M:%SZ')
@@ -84,7 +104,7 @@ def _compose_filter(search_words=None,
     if filter_expired:
         # end_of_day = datetime.utcnow().strftime('%Y-%m-%dT23:59:59Z')
         start_of_day = datetime.utcnow().strftime('%Y-%m-%dT00:00:00Z')
-        filter_phrases.append(f'(fromDateValid%20ge%20{start_of_day})')
+        filter_phrases.append(f'(toDateValid%20ge%20{start_of_day})')
 
     # Filter by Cardholder Type Name
     if cardholder_type_name:
