@@ -46,6 +46,134 @@ class SortAlgorithm(Enum):
     SERVER_DEFAULT = 0,
     FUZZY_MATCH = 1
 
+@dataclass
+class Controller:
+    isActivated: any = None
+    uid: str = ""
+    address: int = 0
+    networkUID: str = ""
+    name: str = ""
+    isPooling: any = None
+    status: str = ""
+    purpose: str = ""
+    isConnected: any = None
+    disconnectTime: str = ""
+    description: any = None
+    script: str = ""
+    firmwareVersion: str = ""
+    hardwareVersion: str = ""
+    apiKey: any = None
+
+    def __init__(self, *args, **kwargs):
+        super().__init__()
+        controller_dict = sanitise_args(self, args, kwargs)
+
+        for property_name in controller_dict:
+            if isinstance(controller_dict[property_name], (str, type(None), bool, int)):
+                setattr(self, property_name, controller_dict[property_name])
+
+    def dict(self):
+        controller_dict = {}
+        for k, v in asdict(self).items():
+            if isinstance(v, (list, dict, bool, int)):
+                controller_dict[k] = v
+            elif isinstance(v, type(None)):
+                controller_dict[k] = None
+            else:
+                controller_dict[k] = str(v)
+
+        return controller_dict
+
+@dataclass
+class Reader:
+    uid: str = ""
+    name: str = ""
+    description: any = None
+    number: int = 0
+    controllerUID: str = ""
+    firstOutputUID: any = None
+    secondOutputUID: any = None
+    weeklyProgramUID: any = None
+    readerFunctionIDs: any = None
+    apiKey: any = None
+    doorAlarmInputUID: str = ""
+    doorControlInput1UID: any = None
+    doorControlInput2UID: any = None
+    doorRemoteInputUID: str = ""
+    motorizedReaderInputUID: any = None
+
+    def __init__(self, *args, **kwargs):
+        super().__init__()
+        reader_dict = sanitise_args(self, args, kwargs)
+
+        for property_name in reader_dict:
+            if isinstance(reader_dict[property_name], (str, type(None), bool, int)):
+                setattr(self, property_name, reader_dict[property_name])
+
+    def dict(self):
+        reader_dict = {}
+        for k, v in asdict(self).items():
+            if isinstance(v, (list, dict, bool, int)):
+                reader_dict[k] = v
+            elif isinstance(v, type(None)):
+                reader_dict[k] = None
+            else:
+                reader_dict[k] = str(v)
+
+        return reader_dict
+
+
+@dataclass
+class Relay(Observable):
+    digitalOutputStatus: str = ""
+    uid: str = ""
+    number: int = 0
+    name: str = ""
+    description: any = None
+    weeklyProgramUID: any = None
+    controllerUID: str = ""
+    liftReaderUID: any = None
+    constantState: str = ""
+    apiKey: any = None
+
+    def __init__(self, *args, **kwargs):
+        super().__init__()
+        relay_dict = sanitise_args(self, args, kwargs)
+
+        for property_name in relay_dict:
+            if isinstance(relay_dict[property_name], (str, type(None), bool, int)):
+                setattr(self, property_name, relay_dict[property_name])
+
+        # Monitor Changes
+        for k, v in asdict(self).items():
+            if isinstance(v, (str, type(None), bool, int)):
+                self.add_observer(k)
+
+    def _remove_non_changed(self, relay_dict: dict):
+        for key, value in list(relay_dict.items()):
+            if key not in self.changed_attributes:
+                relay_dict.pop(key)
+        return relay_dict
+
+    def dict(self, editable_only=False, changed_only=False):
+        relay_dict = {}
+        for k, v in asdict(self).items():
+            if isinstance(v, (list, dict, bool, int)):
+                relay_dict[k] = v
+            elif isinstance(v, type(None)):
+                relay_dict[k] = None
+            else:
+                relay_dict[k] = str(v)
+
+        if editable_only:
+            if 'uid' in relay_dict:
+                relay_dict.pop('uid')
+
+        if changed_only:
+            relay_dict = self._remove_non_changed(relay_dict)
+
+        return relay_dict
+
 
 @dataclass
 class Card(Observable):
